{% import "partials/language.html" as lang with context %}
{% set feature = config.theme.feature %}
{% set palette = config.theme.palette %}
{% set font = config.theme.font %}
<!doctype html>
<html lang="{{ lang.t('language') }}" class="no-js">
  <head>
    {% block site_meta %}
      <meta charset="utf-8">
      <meta name="viewport" content="width=device-width,initial-scale=1">
      <meta http-equiv="x-ua-compatible" content="ie=edge">
      {% if page and page.meta and page.meta.description %}
        <meta name="description" content="{{ page.meta.description }}">
      {% elif config.site_description %}
        <meta name="description" content="{{ config.site_description }}">
      {% endif %}
      {% if page and page.meta and page.meta.redirect %}
        <script>var anchor=window.location.hash.substr(1);location.href="{{ page.meta.redirect }}"+(anchor?"#"+anchor:"")</script>
        <meta http-equiv="refresh" content="0; url={{ page.meta.redirect }}">
        <meta name="robots" content="noindex">
        <link rel="canonical" href="{{ page.meta.redirect }}">
      {% elif page.canonical_url %}
        <link rel="canonical" href="{{ page.canonical_url }}">
      {% endif %}
      {% if page and page.meta and page.meta.author %}
        <meta name="author" content="{{ page.meta.author | first }}">
      {% elif config.site_author %}
        <meta name="author" content="{{ config.site_author }}">
      {% endif %}
      {% for key in [
        "clipboard.copy",
        "clipboard.copied",
        "search.language",
        "search.pipeline.stopwords",
        "search.pipeline.trimmer",
        "search.result.none",
        "search.result.one",
        "search.result.other",
        "search.tokenizer"
      ] %}
        <meta name="lang:{{ key }}" content="{{ lang.t(key) }}">
      {% endfor %}
      <link rel="shortcut icon" href="{{ config.theme.favicon | url }}">
      <meta name="generator" content="mkdocs-{{ mkdocs_version }}, mkdocs-brudi-0.4.0">
    {% endblock %}
    {% block htmltitle %}
      {% if page and page.meta and page.meta.title %}
        <title>{{ page.meta.title }}</title>
      {% elif page and page.title and not page.is_homepage %}
        <title>{{ page.title }} - {{ config.site_name }}</title>
      {% else %}
        <title>{{ config.site_name }}</title>
      {% endif %}
    {% endblock %}
    {% block styles %}
      <link rel="stylesheet" href="{{ 'assets/stylesheets/application.3020aac5.css' | url }}">
      {% if palette.primary or palette.accent %}
        <link rel="stylesheet" href="{{ 'assets/stylesheets/application-palette.c49bd0d0.css' | url }}">
      {% endif %}
      {% if palette.primary %}
        {% import "partials/palette.html" as map %}
        {% set primary = map.primary(
          palette.primary | replace(" ", "-") | lower
        ) %}
        <meta name="theme-color" content="{{ primary }}">
      {% endif %}
    {% endblock %}
    {% block libs %}
      <script src="{{ 'assets/javascripts/modernizr.01ccdecf.js' | url }}"></script>
    {% endblock %}
    {% block fonts %}
      {% if font != false %}
        <link href="https://fonts.gstatic.com" rel="preconnect" crossorigin>
        <link rel="stylesheet" href="https://fonts.googleapis.com/css?family={{
              font.text | replace(' ', '+')  + ':300,400,400i,700|' +
              font.code | replace(' ', '+')
            }}">
        <style>body,input{font-family:"{{ font.text }}","Helvetica Neue",Helvetica,Arial,sans-serif}code,kbd,pre{font-family:"{{ font.code }}","Courier New",Courier,monospace}</style>
      {% endif %}
    {% endblock %}
    <link rel="stylesheet" href="{{ 'assets/fonts/material-icons.css' | url }}">
    {% if config.extra.manifest %}
      <link rel="manifest" href="{{ config.extra.manifest | url }}">
    {% endif %}
    {% for path in config["extra_css"] %}
      <link rel="stylesheet" href="{{ path | url }}">
    {% endfor %}
    {% block analytics %}
      {% if config.google_analytics %}
        {% include "partials/integrations/analytics.html" %}
      {% endif %}
    {% endblock %}
    {% block extrahead %}{% endblock %}
  </head>
  {% if palette.primary or palette.accent %}
    {% set primary = palette.primary | replace(" ", "-") | lower %}
    {% set accent  = palette.accent  | replace(" ", "-") | lower %}
    <body dir="{{ lang.t('direction') }}" data-md-color-primary="{{ primary }}" data-md-color-accent="{{ accent }}">
  {% else %}
    <body dir="{{ lang.t('direction') }}">
  {% endif %}
    <svg class="md-svg">
      <defs>
        {% set platform = config.extra.repo_icon or config.repo_url %}
        {% if "github" in platform %}
          {% include "assets/images/icons/github.f0b8504a.svg" %}
        {% elif "gitlab" in platform %}
          {% include "assets/images/icons/gitlab.6dd19c00.svg" %}
        {% elif "bitbucket" in platform %}
          {% include "assets/images/icons/bitbucket.1b09e088.svg" %}
        {% endif %}
      </defs>
    </svg>
    <input class="md-toggle" data-md-toggle="drawer" type="checkbox" id="__drawer" autocomplete="off">
    <input class="md-toggle" data-md-toggle="search" type="checkbox" id="__search" autocomplete="off">
    <label class="md-overlay" data-md-component="overlay" for="__drawer"></label>
    {% if page.toc | first is defined %}
      <a href="{{ (page.toc | first).url }}" tabindex="1" class="md-skip">
        {{ lang.t('skip.link.title') }}
      </a>
    {% endif %}
    {% block header %}
      {% include "partials/header.html" %}
    {% endblock %}
    <div class="md-container">
      {% block hero %}
        {% if page and page.meta and page.meta.hero %}
          {% include "partials/hero.html" with context %}
        {% endif %}
      {% endblock %}
      {% if feature.tabs %}
        {% include "partials/tabs.html" %}
      {% endif %}
      <main class="md-main">
        <div class="md-main__inner md-grid" data-md-component="container">
          {% block site_nav %}
            {% if nav %}
              <div class="md-sidebar md-sidebar--primary" data-md-component="navigation">
                <div class="md-sidebar__scrollwrap">
                  <div class="md-sidebar__inner">
                    {% include "partials/nav.html" %}
                  </div>
                </div>
              </div>
            {% endif %}
            {% if page.toc %}
              <div class="md-sidebar md-sidebar--secondary" data-md-component="toc">
                <div class="md-sidebar__scrollwrap">
                  <div class="md-sidebar__inner">
                    {% include "partials/toc.html" %}
                  </div>
                </div>
              </div>
            {% endif %}
          {% endblock %}
          <div class="md-content">
            <article class="md-content__inner md-typeset">
              {% block content %}
                {% if page.edit_url %}
                  <a href="{{ page.edit_url }}" title="{{ lang.t('edit.link.title') }}" class="md-icon md-content__icon">&#xE3C9;</a>
                {% endif %}
                {% if not "\x3ch1" in page.content %}
                  <h1>{{ page.title | default(config.site_name, true)}}</h1>
                {% endif %}
                {{ page.content }}
                {% block source %}
                  {% if page and page.meta and page.meta.source %}
                    <h2 id="__source">{{ lang.t("meta.source") }}</h2>
                    {% set repo = config.repo_url %}
                    {% if repo | last == "/" %}
                      {% set repo = repo[:-1] %}
                    {% endif %}
                    {% set path = page.meta.path | default([""]) %}
                    {% set file = page.meta.source %}
                    <a href="{{ [repo, path, file] | join('/') }}" title="{{ file }}" class="md-source-file">
                      {{ file }}
                    </a>
                  {% endif %}
                {% endblock %}
              {% endblock %}
              {% block disqus %}
                {% include "partials/integrations/disqus.html" %}
              {% endblock %}
            </article>
          </div>
        </div>
      </main>
      {% block footer %}
        {% include "partials/footer.html" %}
      {% endblock %}
    </div>
    {% block scripts %}
      <script src="{{ 'assets/javascripts/application.c3e02f1d.js' | url }}"></script>
      {% if lang.t("search.language") != "en" %}
        {% set languages = lang.t("search.language").split(",") %}
        {% if languages | length and languages[0] != "" %}
          {% set path = "assets/javascripts/lunr/" %}
          <script src="{{ (path ~ 'lunr.stemmer.support.js') | url }}"></script>
          {% for language in languages | map("trim") %}
            {% if language != "en" %}
              {% if language == "ja" %}
                <script src="{{ (path ~ 'tinyseg.js') | url }}"></script>
              {% endif %}
              {% if language in ("da", "de", "es", "fi", "fr", "hu", "it", "ja", "nl", "no", "pt", "ro", "ru", "sv", "th", "tr") %}
                <script src="{{ (path ~ 'lunr.' ~ language ~ '.js') | url }}"></script>
              {% endif %}
            {% endif %}
          {% endfor %}
          {% if languages | length > 1 %}
            <script src="{{ (path ~ 'lunr.multi.js') | url }}"></script>
          {% endif %}
        {% endif %}
      {% endif %}
      <script>app.initialize({version:"{{ mkdocs_version }}",url:{base:"{{ base_url }}"}})</script>
      {% for path in config["extra_javascript"] %}
        <script src="{{ path | url }}"></script>
      {% endfor %}
    {% endblock %}
  </body>
</html>
