{% import "partials/language/" + config.theme.language + ".html" as lang %}
{% import "partials/language/en.html" as fallback %}
{% macro t(key) %}{{ {
  "direction": config.theme.direction,
  "search.language": (
    config.extra.search | default({})
  ).language,
  "search.tokenizer": (
    config.extra.search | default({})
  ).tokenizer | default("", true),
}[key] or lang.t(key) or fallback.t(key) }}{% endmacro %}
