{% macro t(key) %}{{ {
  "language": "uk",
  "clipboard.copy": "Скопіювати в буфер",
  "clipboard.copied": "Скопійовано в буфер",
  "edit.link.title": "Редагувати сторінку",
  "footer.previous": "Назад",
  "footer.next": "Вперед",
  "meta.comments": "Коментарі",
  "meta.source": "Вихідний код",
  "search.language": "ru",
  "search.placeholder": "Пошук",
  "search.result.placeholder": "Розпочніть писати для пошуку",
  "search.result.none": "Збігів не знайдено",
  "search.result.one": "Знайдено 1 збіг",
  "search.result.other": "Знайдено # збігів",
  "skip.link.title": "Перейти до змісту",
  "source.link.title": "Перейти до репозиторію",
  "toc.title": "Зміст"
}[key] }}{% endmacro %}
