{% macro t(key) %}{{ {
  "language": "sv",
  "clipboard.copy": "Kopiera till urklipp",
  "clipboard.copied": "Kopierat till urklipp",
  "edit.link.title": "Redigera sidan",
  "footer.previous": "Föregående",
  "footer.next": "Nästa",
  "meta.comments": "Kommentarer",
  "meta.source": "Källa",
  "search.language": "sv",
  "search.placeholder": "Sök",
  "search.result.placeholder": "Skriv sökord",
  "search.result.none": "Inga sökresultat",
  "search.result.one": "1 sökresultat",
  "search.result.other": "# sökresultat",
  "skip.link.title": "Gå till innehållet",
  "source.link.title": "Gå till datakatalog",
  "toc.title": "Innehållsförteckning"
}[key] }}{% endmacro %}
